@@ -710,6 +710,7 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 		# change data coding
 		for(i in 2:dim(data)[2]){
 			data[, i] <- as.character(data[, i])
+			if(colnames(data)[i] %in% subpop) next
 			# Notice for WHO 2012 input, NA will be converted to absence
 			if(sum(is.na(data[, i])) > 0){
 				data[which(is.na(data[, i])), i] <- "."
@@ -881,6 +882,14 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 		    vacauses <- causetext[4:64,2]
 		    external.causes = seq(50, 60)
 		    external.symps = seq(20, 38)
+		    # These are codes to verify the external causes and symptoms are correct when probbase is updated
+		    if(FALSE){
+		    	test_symps <- valabels[-1]
+		    	test_ext_symps <- probbaseV5[match(test_symps[external.symps], probbaseV5[,1]), 2]
+		    	test_ext_causes <- vacauses[external.causes]
+		    	print(test_ext_symps)
+		    	print(test_ext_causes)
+		    }
 
 		}else{
 			stop("Wrong data.type, need to be WHO2012 or WHO2016")
@@ -1468,7 +1477,8 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 	theta.last.j <- .jarray(matrix(0, N_sub.j, C), dispatch = TRUE)
 	keepProb.j <- !updateCondProb
 
-	ins  <- .jcall(obj, "[D", "Fit", 
+	ins <- try( 
+		.jcall(obj, "[D", "Fit", 
 		dimensions.j, 
 		probbase.j, probbase_order.j, level_values.j, 
 		prior_a.j, prior_b.j, jumprange.j, trunc_min.j, trunc_max.j, 
@@ -1477,6 +1487,12 @@ ParseResult <- function(N_sub.j, C.j, S.j, N_level.j, pool.j, fit){
 		mu.j, sigma2.j, isUnix, keepProb.j, 
 		isAdded, mu.last.j, sigma2.last.j, theta.last.j, 
 		C.phy.j, vacauses.broader.j, assignment.j, impossible.j) 
+		, FALSE)
+	if(is(ins, "try-error")){
+		java_message()	
+		stop()
+	}
+
     # one dimensional array is straightforward
     fit <- ins
     # fit <-  .jeval(ins, .jevalArray))
@@ -1711,3 +1727,9 @@ if(!is.null(indiv.CI)){
 class(out) <- "insilico"
 return(out)  	
 } 
+
+#' Message to set heap size for Java
+#' @keywords internal
+java_message <- function(){
+	message("\nIf you receive Java heap space error, try re-starting R and run this line, *before* loading any libraries:\n  options(java.parameters = c('-Xmx2g'))\nThis line allocates 2GB of memory to Java. You can change the memory size by modifying the parameter '-Xmx2g'.")
+}
\ No newline at end of file
